@@ -17,12 +17,13 @@ setClass(
 
              nMargins  <- length(object@margins[!is.na(object@margins)])
 
-             if(nMargins<2){stop("At least 2 elements of 'margins' must not be NA in order to calibrate demand parameters")}
+             if(nMargins<2 && is.na(object@mktElast)){stop("At least 2 elements of 'margins' must not be NA in order to calibrate demand parameters")}
 
-             if(object@shareInside!=1){
-                 stop(" sum of 'shares' must equal 1")
+             if(object@shareInside != 1){
+               stop(" sum of 'shares' must equal 1")
              }
-
+             
+             
               if(length(object@parmsStart)!=2){
                  stop("'parmsStart' must a vector of length 2")
                  }
@@ -40,6 +41,9 @@ setMethod(
               shares       <-  object@shares
               margins      <-  object@margins
               prices       <-  object@prices
+              mktElast     <-  object@mktElast 
+              
+              avgPrice <- sum(shares*prices)
 
               nprods <- length(object@shares)
 
@@ -60,7 +64,10 @@ setMethod(
 
                   revenues <- probs * prices
                   marginsCand <- -1 * as.vector(ginv(elast * ownerPre) %*% (revenues * diag(ownerPre))) / revenues
-                  measure <- sum((margins - marginsCand)^2,na.rm=TRUE)
+                  
+                  m1 <- margins - marginsCand
+                  m2 <- mktElast/(avgPrice * alpha) - sOut  
+                  measure <- sum(c(m1,m2)^2,na.rm=TRUE)
 
                   #elast      <-   elast[isMargin,isMargin]
                   #revenues   <-   revenues[isMargin]
@@ -80,12 +87,17 @@ setMethod(
               lowerB <- c(-Inf,0)
               upperB <- c(-1e-10,.99999)
 
+              
+              if(!is.na(mktElast)){
+                upperB[1] <- mktElast/avgPrice
+              }
+              
               minTheta <- optim(object@parmsStart,minD,
                                 method="L-BFGS-B",
                                 lower= lowerB,upper=upperB,
                                 control=object@control.slopes)$par
 
-              if(isTRUE(all.equal(minTheta[2],0,check.names=FALSE))){stop("ERROR: Estimated outside share is close to 0. Use `logit' function instead")}
+              if(isTRUE(all.equal(minTheta[2],0,check.names=FALSE))){warning("Estimated outside share is close to 0. Use `logit' function instead")}
               
               meanval <- log(shares * (1 - minTheta[2])) - log(minTheta[2]) - minTheta[1] * (prices - object@priceOutside)
 
@@ -104,6 +116,7 @@ setMethod(
 
 logit.alm <- function(prices,shares,margins,
                       ownerPre,ownerPost,
+                      mktElast = NA_real_,
                       mcDelta=rep(0,length(prices)),
                       subset=rep(TRUE,length(prices)),
                       priceOutside=0,
@@ -130,11 +143,12 @@ logit.alm <- function(prices,shares,margins,
                   margins=margins,
                   ownerPre=ownerPre,
                   ownerPost=ownerPost,
+                  mktElast = mktElast,
                   mcDelta=mcDelta,
                   subset=subset,
                   priceOutside=priceOutside,
                   priceStart=priceStart,
-                  shareInside=sum(shares),
+                  shareInside=ifelse(isTRUE(all.equal(sum(shares),1,check.names=FALSE,tolerance=1e-3)),1,sum(shares)),
                   parmsStart=parmsStart,
                   labels=labels)
 
